@@ -3,17 +3,17 @@
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef AKONADI_PUBLISHDIALOG_H
-#define AKONADI_PUBLISHDIALOG_H
+#pragma once
 
 #include "akonadi-calendar_export.h"
 
 #include <KCalendarCore/Attendee>
 #include <QDialog>
 
-//TODO: documentation
+// TODO: documentation
 // Uses akonadi-contact, so don't move this class to KCalUtils.
-namespace Akonadi {
+namespace Akonadi
+{
 class AKONADI_CALENDAR_EXPORT PublishDialog : public QDialog
 {
     Q_OBJECT
@@ -53,4 +53,3 @@ private:
 };
 }
 
-#endif
